.popup
{
  width: 100%;
  height: 100%;
  min-height: 100%;
  position: absolute;
  z-index: 100000;
  top: 0;
  left: 0;
  display: none;
}
.popup-background
{
  background: #eee;
  display: block;
  filter:progid:DXImageTransform.Microsoft.Alpha(opacity=50);
  height: 100%;
  left: 0;
  min-height: 100%;
  opacity: .50;
  position: fixed;
  top: 0;
  width: 100%;
  z-index: 100001;
}
  .popup-inner
  {
    //top: 50%;
    //vertical-align: baseline;
    display: table-cell;
    position: relative;
    vertical-align: middle;
    width: 100%;
  }
    .popup-inner__ie
    {
      position: relative;
      width: 100%;
      text-align: center;
      //top: -50%;
    }
      .popup-inner__content
      {
        position: relative;
        z-index: 100002;
        display: inline-block;
        margin: 2em 0;
        text-align: left;
        text-decoration: none;
      }
        .popup-inner__content-link
        {
          position: absolute;
          z-index: 100003;
          top: .1em;
          right: 1.3em;
          text-decoration: none;
        }
          .popup-inner__content-link-text
          {
            font: .9em 'Arial', Helvetica, sans-serif;
            cursor: pointer;
            color: #000;
            border-bottom: dashed 1px #000;
          }
        .popup-inner__content-link:hover .popup-inner__content-link-text
        {
          color: #ff6702;
          border-bottom: dashed 1px #ff6702;
        }
