.page
{
    border: solid 1px #bbb;
    position: relative;
    z-index: 90;
    box-shadow: 0 0 1.5em #ccc;
}
    .page-inner
    {
        width: 100%;
        display: table;
    }
        .page__left
        {
            width: 23%;
            display: table-cell;
            background: #eee;
            vertical-align: top;
        }
        .page__middle
        {
            width: 50%;
            display: table-cell;
            padding: 2em 3% 2em 4%;
            vertical-align: top;
        }
        .page__right
        {
            width: 20%;
            display: table-cell;
            vertical-align: top;
            background: #eee;
        }