.gallery-list
{
  display: table;
}
  .gallery-list__item
  {
    min-height: 100px;
    display: inline-block;
    vertical-align: top;
    zoom: 1;
    *display: inline;
    _height: 100px;
    margin: 0 0 2em 0;
  }
      .gallery-list__item-link
      {
        display: inline-block;
        text-decoration: none;
        border: solid 3px #fff;
        padding: 0.1em;
        width: 150px;
        position: relative;
      }
        .gallery-list__item-image
        {
          width: 100%;
          display: inline-block;
          position: relative;
          box-shadow: #bbb 0 1px 3px;
          vertical-align: bottom;
        }
      .gallery-list__item-link:hover
      {
        border: solid 3px #bc2131;
      }